@@ -72,6 +72,11 @@ ConvRule romakana_table[] = {
     {"chu",	"ちゅ",	""},
     {"che",	"ちぇ",	""},
     {"cho",	"ちょ",	""},
+    {"ca",	"か",	""},
+    {"ci",	"し",	""},
+    {"cu",	"く",	""},
+    {"ce",	"せ",	""},
+    {"co",	"こ",	""},
     {"dya",	"ぢゃ",	""},
     {"dyi",	"ぢぃ",	""},
     {"dyu",	"ぢゅ",	""},
@@ -293,6 +298,23 @@ ConvRule romakana_table[] = {
     {"`",	"‘",	""},
     {"@",	"＠",	""},
     {"{",	"｛",	""},
+#else
+    {"\"",	"\"",	""},
+    {"#",	"#",	""},
+    {"$",	"$",	""},
+    {"%",	"%",	""},
+    {"&",	"&",	""},
+    {"'",	"'",	""},
+    {"(",	"(",	""},
+    {")",	")",	""},
+    {"~",	"~",	""},
+    {"=",	"=",	""},
+    {"^",	"^",	""},
+    {"\\",	"\\",	""},
+    {"|",	"|",	""},
+    {"`",	"`",	""},
+    {"@",	"@",	""},
+    {"{",	"{",	""},
 #endif
     {"[",	"「",	""},
 #if 0
@@ -301,17 +323,38 @@ ConvRule romakana_table[] = {
     {"*",	"＊",	""},
     {":",	"：",	""},
     {"}",	"｝",	""},
+#else
+    {"+",	"+",	""},
+    {";",	";",	""},
+    {"*",	"*",	""},
+    {":",	":",	""},
+    {"}",	"}",	""},
 #endif
     {"]",	"」",	""},
 #if 0
     {"<",	"＜",	""},
     {">",	"＞",	""},
+#else
+    {"<",	"<",	""},
+    {">",	">",	""},
 #endif
     {"?",	"？",	""},
-    {"/",	"／",	""},
+    {"/",	"/",	""},
 #if 0
     {"_",	"＿",	""},
+#else
+    {"_",	"_",	""},
 #endif
+    {"1",	"1",	""},
+    {"2",	"2",	""},
+    {"3",	"3",	""},
+    {"4",	"4",	""},
+    {"5",	"5",	""},
+    {"6",	"6",	""},
+    {"7",	"7",	""},
+    {"8",	"8",	""},
+    {"9",	"9",	""},
+    {"0",	"0",	""},
 #endif
     {NULL,	NULL,	NULL}
 };
@@ -444,16 +487,6 @@ ConvRule kana_ascii_period_rule[] = {
     {NULL,	NULL,	NULL},
 };
 
-ConvRule wide_space_rule[] = {
-    {" ",	"　",	""},
-    {NULL,	NULL,	NULL},
-};
-
-ConvRule space_rule[] = {
-    {" ",	" ",	""},
-    {NULL,	NULL,	NULL},
-};
-
 HiraganaKatakanaRule hiragana_katakana_table[] = {
     {"あ", "ア", "ｱ"},
     {"い", "イ", "ｲ"},
@@ -684,6 +717,7 @@ WideRule wide_table[] = {
     {"?", "？"},
     {"/", "／"},
     {"_",  "＿"},
+    {" ",	"　"},
     {NULL, NULL},
 };
 
