@@ -35,7 +35,7 @@ SKKAutomaton::~SKKAutomaton ()
 
 bool
 SKKAutomaton::append (const String & str,
-                   WideString & result, WideString & pending)
+                      WideString & result, WideString & pending)
 {
     WideString widestr = utf8_mbstowcs (str);
     WideString newstr = m_pending + widestr;
@@ -77,29 +77,30 @@ SKKAutomaton::append (const String & str,
         result            = utf8_mbstowcs (exact_match->result);
         pending           = m_pending;
     } else {
+        retval = true; /* commit prev pending */
         if (m_exact_match) {
+            WideString tmp_result;
+
             if (m_exact_match->result && *m_exact_match->result &&
-                (!m_exact_match->cont || !*m_exact_match->cont))
-            {
+                (!m_exact_match->cont || !*m_exact_match->cont)) {
                 result = utf8_mbstowcs (m_exact_match->result);
-            } else {
-                retval = true; /* commit prev pending */
             }
             m_pending.clear ();
             m_exact_match = NULL;
 
-            WideString tmp_result;
             append(str, tmp_result, pending);
             result += tmp_result;
         } else {
             if (m_pending.length () > 0) {
-                retval     = true; /* commit prev pending */
-                m_pending  = widestr;
-                pending    = m_pending;
-                result.clear();
+                m_pending.clear();
+                pending.clear();
+                append(str, result, pending);
             } else {
                 result.clear();
-                pending = widestr;
+                for (int i = 0; i < str.size(); i++) {
+                    if (isalpha(str[i]))
+                        pending += widestr[i];
+                }
                 m_pending = pending;
             }
         }
