@@ -27,6 +27,7 @@
 #include <scim.h>
 
 #include "scim_skk_lookup_table.h"
+#include "scim_skk_history.h"
 
 using namespace scim;
 
@@ -49,9 +50,8 @@ public:
     SKKDictionary  (void);
     ~SKKDictionary (void);
 
-    void add_sysdict  (const String &dictname);
-    void set_userdict (const String &dictname);
-    void add_skkserv  (const String &host, const int port = -1);
+    void add_sysdict  (const String &dicturi);
+    void set_userdict (const String &dictname, History &hist);
 
     void dump_userdict (void);
 
